==> miniorange_2fa-8.x-4.1.tar.gz: miniorange_2fa/src/Form/MoAuthPhoneUpdate.php <==
<?php

namespace Drupal\miniorange_2fa\Form;

use Drupal\Core\Url;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\ReplaceCommand;
use Drupal\Core\Ajax\RedirectCommand;
use Drupal\Core\Form\FormStateInterface;
use Drupal\miniorange_2fa\MoAuthUtilities;

class MoAuthPhoneUpdate extends FormBase
{
    public function getFormId() {
        return 'miniorange_2fa_phone_udate';
    }

    public function buildForm(array $form, FormStateInterface $form_state, $options = NULL) {

        $utilities = new MoAuthUtilities();
        $custom_attribute = $utilities::get_users_custom_attribute(\Drupal::currentUser()->id());

        $form['markup_library'] = array(
            '#attached' => array(
                'library' => array(
                    "miniorange_2fa/miniorange_2fa.admin",
                    "miniorange_2fa/miniorange_2fa.license",
                )
            ),
        );

        $form['miniorange_2fa_update_phone'] = array(
            '#markup' => t('You can update your phone number here. The updated phone number will be used for 2FA upon next login.')
        );

        $form['miniorange_2fa_update_phone']['phone_number'] = array(
            '#type' => 'textfield',
            '#title' => t('Enter Updated Phone number'),
            '#id' => 'query_phone',
            '#description' => t('<strong>Note:</strong> Enter phone number with country code Eg. +00xxxxxxxxxx'),
            '#attributes' => array(
                'class' => array('query_phone',),
                'pattern' => '[\+]?[0-9]{1,4}\s?[0-9]{7,12}',
                'placeholder' => t('Enter phone number with country code Eg. +00xxxxxxxxxx'),
                'style' => 'width:60%'
            ),
            '#default_value' => $custom_attribute[0]->phone_number,
        );

        $form['actions'] = array('#type' => 'actions');
        $form['actions']['send'] = [
            '#type' => 'submit',
            '#value' => $this->t('Update'),
            '#attributes' => [
                'class' => [
                    'use-ajax',
                    'button--primary'
                ],
            ],
            '#ajax' => [
                'callback' => [$this, 'submitModalFormAjax'],
                'event' => 'click',
            ],
        ];

        $form['#attached']['library'][] = 'core/drupal.dialog.ajax';
        return $form;
    }

    public function submitModalFormAjax(array $form, FormStateInterface $form_state) {
        $response = new AjaxResponse();
        // If there are any form errors, AJAX replace the form.
        if ( $form_state->hasAnyErrors() ) {
            $response->addCommand(new ReplaceCommand('#modal_support_form', $form));
        }else {
            $form_state->setRebuild();
            $user_id = \Drupal::currentUser()->id();
            $utilities = new MoAuthUtilities();

            $form_values = $form_state->getValues();
            $updated_phone = $form_values['phone_number'];

            $available = $utilities::check_for_userID($user_id);
            $database = \Drupal::database();
            if ($available == TRUE) {
                $database->update('UserAuthenticationType')->fields(['phone_number' => $updated_phone])->condition('uid', $user_id, '=')->execute();
            } else {
                \Drupal::messenger()->addError(t("error while saving the authentication method."));
                return;
            }

            $message = t('Phone Number updated successfully.');
            \Drupal::messenger()->addStatus($message);
            $url = Url::fromRoute('miniorange_2fa.user.mo_mfa_form', ['user' => $user_id] )->toString();
            $response->addCommand( new RedirectCommand( $url ) );
            return $response;
        }
    }

    public function validateForm(array &$form, FormStateInterface $form_state) { }

    public function submitForm(array &$form, FormStateInterface $form_state) { }
}

==> miniorange_2fa-8.x-4.5.tar.gz: miniorange_2fa/src/Form/MoAuthPhoneUpdate.php <==
<?php

namespace Drupal\miniorange_2fa\Form;

use Drupal\Core\Url;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\ReplaceCommand;
use Drupal\Core\Ajax\RedirectCommand;
use Drupal\Core\Form\FormStateInterface;
use Drupal\miniorange_2fa\MoAuthUtilities;

class MoAuthPhoneUpdate extends FormBase
{
    public function getFormId() {
        return 'miniorange_2fa_phone_udate';
    }

    public function buildForm(array $form, FormStateInterface $form_state, $options = NULL) {

        $utilities = new MoAuthUtilities();
        $custom_attribute = $utilities::get_users_custom_attribute(\Drupal::currentUser()->id());

        $form['markup_library'] = array(
            '#attached' => array(
                'library' => array(
                    "miniorange_2fa/miniorange_2fa.admin",
                    "miniorange_2fa/miniorange_2fa.license",
                )
            ),
        );

        $form['miniorange_2fa_update_phone'] = array(
            '#markup' => t('You can update your phone number here. The updated phone number will be used for 2FA upon next login.')
        );

        $form['miniorange_2fa_update_phone']['phone_number'] = array(
            '#type' => 'textfield',
            '#title' => t('Enter Updated Phone number'),
            '#id' => 'query_phone',
            '#description' => t('<strong>Note:</strong> Enter phone number with country code Eg. +00xxxxxxxxxx'),
            '#attributes' => array(
                'class' => array('query_phone',),
                'pattern' => '[\+]?[0-9]{1,4}\s?[0-9]{7,12}',
                'placeholder' => t('Enter phone number with country code Eg. +00xxxxxxxxxx'),
                'style' => 'width:60%'
            ),
            '#default_value' => $custom_attribute[0]->phone_number,
        );

        $form['actions'] = array('#type' => 'actions');
        $form['actions']['send'] = [
            '#type' => 'submit',
            '#value' => $this->t('Update'),
            '#attributes' => [
                'class' => [
                    'use-ajax',
                    'button--primary'
                ],
            ],
            '#ajax' => [
                'callback' => [$this, 'submitModalFormAjax'],
                'event' => 'click',
            ],
        ];

        $form['#attached']['library'][] = 'core/drupal.dialog.ajax';
        return $form;
    }

    public function submitModalFormAjax(array $form, FormStateInterface $form_state) {
        $response = new AjaxResponse();
        // If there are any form errors, AJAX replace the form.
        if ( $form_state->hasAnyErrors() ) {
            $response->addCommand(new ReplaceCommand('#modal_support_form', $form));
        }else {
            $form_state->setRebuild();
            $user_id = \Drupal::currentUser()->id();
            $utilities = new MoAuthUtilities();

            $form_values = $form_state->getValues();
            $updated_phone = $form_values['phone_number'];

            $available = $utilities::check_for_userID($user_id);
            $database = \Drupal::database();
            if ($available == TRUE) {
                $database->update('UserAuthenticationType')->fields(['phone_number' => $updated_phone])->condition('uid', $user_id, '=')->execute();
            } else {
                \Drupal::messenger()->addError(t("Error while updating the phone number"));
                return;
            }

            $message = t('Phone Number updated successfully.');
            \Drupal::messenger()->addStatus($message);
            $url = Url::fromRoute('miniorange_2fa.user.mo_mfa_form', ['user' => $user_id] )->toString();
            $response->addCommand( new RedirectCommand( $url ) );
            return $response;
        }
    }

    public function validateForm(array &$form, FormStateInterface $form_state) { }

    public function submitForm(array &$form, FormStateInterface $form_state) { }
}
